import { defineComponent, computed, pushScopeId, popScopeId, withDirectives, openBlock, createElementBlock, normalizeClass, normalizeStyle, createElementVNode, Fragment, createCommentVNode, vShow } from 'vue';

const validFlip = [
    'horizontal',
    'vertical',
    'both',
];
const validPull = [
    'right',
    'left',
];

var script = defineComponent({
  props: {
    icon: {
      type: Object,
      required: true
    },
    size: {
      type: String,
      validator: function validator(value) {
        return /^(lg|xs|sm|([\d.]+)x)$/.test(value);
      }
    },
    color: String,
    fw: Boolean,
    pull: {
      type: String,
      validator: function validator(value) {
        return validPull.indexOf(value) >= 0;
      }
    },
    flip: {
      type: String,
      validator: function validator(value) {
        return validFlip.indexOf(value) >= 0;
      }
    },
    rotate: {
      type: [Number, String],
      validator: function validator(value) {
        return /^[-\d.]+$/.test("" + value);
      }
    },
    spin: Boolean,
    pulse: Boolean,
    primaryColor: String,
    secondaryColor: String,
    primaryOpacity: {
      type: [Number, String],
      default: 1
    },
    secondaryOpacity: {
      type: [Number, String],
      default: 0.4
    },
    swapOpacity: Boolean
  },
  setup: function setup(props) {
    var i = function i() {
      var _props$icon$icon, _props$icon;

      return (_props$icon$icon = (_props$icon = props.icon) == null ? void 0 : _props$icon.icon) != null ? _props$icon$icon : [0, 0, '', [], ''];
    };

    return {
      i: computed(i),
      style: computed(function () {
        if (!i()[4]) {
          return {};
        }

        var base = {
          height: '1em',
          overflow: 'visible',
          verticalAlign: '-.125em'
        };
        var fw = props.fw,
            pull = props.pull,
            size = props.size;

        if (fw) {
          base.textAlign = 'center';
          base.width = '1.25em';
        }

        if (pull) {
          base.float = pull;
        }

        if (size) {
          if (size === 'lg') {
            base.fontSize = '1.33333em';
            base.lineHeight = '.75em';
            base.verticalAlign = '-.225em';
          } else if (size === 'xs') {
            base.fontSize = '.75em';
          } else if (size === 'sm') {
            base.fontSize = '.875em';
          } else {
            base.fontSize = size.replace('x', 'em');
          }
        }

        return base;
      }),
      transform: computed(function () {
        var flip = props.flip,
            rotate = props.rotate;
        var transform = '';

        if (flip) {
          var flipX = 1;
          var flipY = 1;

          if (flip === 'horizontal') {
            flipX = -1;
          } else if (flip === 'vertical') {
            flipY = -1;
          } else {
            flipX = flipY = -1;
          }

          transform += " scale(" + flipX + " " + flipY + ")";
        }

        if (rotate) {
          transform += " rotate(" + rotate + " 0 0)";
        }

        return transform;
      })
    };
  }
});

pushScopeId("data-v-7e44f4d4");

var _hoisted_1 = ["viewBox"];
var _hoisted_2 = ["transform", "transform-origin"];
var _hoisted_3 = ["transform"];
var _hoisted_4 = ["d", "fill"];
var _hoisted_5 = ["d", "fill", "fill-opacity"];
var _hoisted_6 = ["d", "fill", "fill-opacity"];

popScopeId();

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return withDirectives((openBlock(), createElementBlock("svg", {
    viewBox: "0 0 " + _ctx.i[0] + " " + _ctx.i[1],
    class: normalizeClass({
      spin: _ctx.spin,
      pulse: _ctx.pulse
    }),
    style: normalizeStyle(_ctx.style),
    "aria-hidden": "true",
    role: "img",
    xmlns: "http://www.w3.org/2000/svg"
  }, [_ctx.i[4] ? (openBlock(), createElementBlock("g", {
    key: 0,
    transform: "translate(" + _ctx.i[0] / 2 + " " + _ctx.i[1] / 2 + ")",
    "transform-origin": _ctx.i[0] / 4 + " 0"
  }, [createElementVNode("g", {
    transform: _ctx.transform
  }, [typeof _ctx.i[4] === 'string' ? (openBlock(), createElementBlock("path", {
    key: 0,
    d: _ctx.i[4],
    fill: _ctx.color || _ctx.primaryColor || 'currentColor',
    transform: "translate(-256 -256)"
  }, null, 8
  /* PROPS */
  , _hoisted_4)) : (openBlock(), createElementBlock(Fragment, {
    key: 1
  }, [createElementVNode("path", {
    d: _ctx.i[4][0],
    fill: _ctx.secondaryColor || _ctx.color || 'currentColor',
    "fill-opacity": _ctx.swapOpacity !== false ? _ctx.primaryOpacity : _ctx.secondaryOpacity,
    transform: "translate(-256 -256)"
  }, null, 8
  /* PROPS */
  , _hoisted_5), createElementVNode("path", {
    d: _ctx.i[4][1],
    fill: _ctx.primaryColor || _ctx.color || 'currentColor',
    "fill-opacity": _ctx.swapOpacity !== false ? _ctx.secondaryOpacity : _ctx.primaryOpacity,
    transform: "translate(-256 -256)"
  }, null, 8
  /* PROPS */
  , _hoisted_6)], 64
  /* STABLE_FRAGMENT */
  ))], 8
  /* PROPS */
  , _hoisted_3)], 8
  /* PROPS */
  , _hoisted_2)) : createCommentVNode("v-if", true)], 14
  /* CLASS, STYLE, PROPS */
  , _hoisted_1)), [[vShow, _ctx.i[4]]]);
}

function styleInject(css, ref) {
  if (ref === void 0) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') {
    return;
  }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "@-webkit-keyframes spin-7e44f4d4{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes spin-7e44f4d4{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}.spin[data-v-7e44f4d4]{-webkit-animation:spin-7e44f4d4 2s 0s infinite linear;animation:spin-7e44f4d4 2s 0s infinite linear}.pulse[data-v-7e44f4d4]{-webkit-animation:spin-7e44f4d4 1s infinite steps(8);animation:spin-7e44f4d4 1s infinite steps(8)}";
styleInject(css_248z);

script.render = render;
script.__scopeId = "data-v-7e44f4d4";
script.__file = "src/fa.vue";

export default script;
